| Title: | Computes some Measures of OLL-G Family of Distributions |
|---|---|
| Description: | Computes the pdf, cdf, quantile function, hazard function and generating random numbers for Odd log-logistic family (OLL-G). This family have been developed by different authors in the recent years. See Alizadeh (2019) <doi:10.31801/cfsuasmas.542988> for example. |
| Authors: | Danial Mazarei [aut, cre], Hossein Haghbin [aut] (ORCID: <https://orcid.org/0000-0001-8416-2354>), Morad Alizadeh [aut] |
| Maintainer: | Danial Mazarei <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 1.0.0 |
| Built: | 2026-06-06 08:39:45 UTC |
| Source: | https://github.com/dmazarei/ollg |
Computes the pdf, cdf, hdf, quantile and random numbers of the beta extended distribution due to Haghbin et al. (2017) specified by the pdf
for any valid continuous cdf , , the corresponding pdf, , the first shape parameter, and , the second shape parameter.
panollg(x, alpha = 1, beta = 1, G = pnorm, ...) danollg(x, alpha = 1, beta = 1, G = pnorm, ...) qanollg(q, alpha = 1, beta = 1, G = pnorm, ...) ranollg(n, alpha = 1, beta = 1, G = pnorm, ...) hanollg(x, alpha = 1, beta = 1, G = pnorm, ...)panollg(x, alpha = 1, beta = 1, G = pnorm, ...) danollg(x, alpha = 1, beta = 1, G = pnorm, ...) qanollg(q, alpha = 1, beta = 1, G = pnorm, ...) ranollg(n, alpha = 1, beta = 1, G = pnorm, ...) hanollg(x, alpha = 1, beta = 1, G = pnorm, ...)
x |
scaler or vector of values at which the pdf or cdf needs to be computed. |
alpha |
the value of the first shape parameter, must be positive, the default is 1. |
beta |
the value of the second shape parameter, must be positive, the default is 1. |
G |
A baseline continuous cdf. |
... |
The baseline cdf parameters. |
q |
scaler or vector of probabilities at which the quantile needs to be computed. |
n |
number of random numbers to be generated. |
panollg gives the distribution function,
danollg gives the density,
qanollg gives the quantile function,
hanollg gives the hazard function and
ranollg generates random variables from the A New Odd log-logistic family of
distributions (ANOLL-G) for baseline cdf G.
Haghbin, Hossein, et al. "A new generalized odd log-logistic family of distributions." Communications in Statistics-Theory and Methods 46.20(2017): 9897-9920.
x <- seq(0, 1, length.out = 21) panollg(x) panollg(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) danollg(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) curve(danollg, -3, 3) qanollg(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) n <- 10 ranollg(n, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) hanollg(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) curve(hanollg, -3, 3)x <- seq(0, 1, length.out = 21) panollg(x) panollg(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) danollg(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) curve(danollg, -3, 3) qanollg(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) n <- 10 ranollg(n, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) hanollg(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) curve(hanollg, -3, 3)
Computes the pdf, cdf, hdf, quantile and random numbers of the beta extended distribution due to Cordeiro et al. (2016) specified by the pdf
for any valid continuous cdf , , the corresponding pdf, , the beta function, , the shape parameter, , the first shape parameter.
pbollg(x, alpha = 1, a = 1, b = 1, G = pnorm, ...) dbollg(x, alpha = 1, a = 1, b = 1, G = pnorm, ...) qbollg(q, alpha = 1, a = 1, b = 1, G = pnorm, ...) rbollg(n, alpha = 1, a = 1, b = 1, G = pnorm, ...) hbollg(x, alpha = 1, a = 1, b = 1, G = pnorm, ...)pbollg(x, alpha = 1, a = 1, b = 1, G = pnorm, ...) dbollg(x, alpha = 1, a = 1, b = 1, G = pnorm, ...) qbollg(q, alpha = 1, a = 1, b = 1, G = pnorm, ...) rbollg(n, alpha = 1, a = 1, b = 1, G = pnorm, ...) hbollg(x, alpha = 1, a = 1, b = 1, G = pnorm, ...)
x |
scaler or vector of values at which the pdf or cdf needs to be computed. |
alpha |
the value of the first shape parameter, must be positive, the default is 1. |
a |
the value of the shape parameter, must be positive, the default is 1. |
b |
the value of the shape parameter, must be positive, the default is 1. |
G |
A baseline continuous cdf. |
... |
The baseline cdf parameters. |
q |
scaler or vector of probabilities at which the quantile needs to be computed. |
n |
number of random numbers to be generated. |
pbollg gives the distribution function,
dbollg gives the density,
qbollg gives the quantile function,
hbollg gives the hazard function and
rbollg generates random variables from the The beta Odd log-logistic family of
distributions (BOLL-G) for baseline cdf G.
Cordeiro, G. M., Alizadeh, M., Tahir, M. H., Mansoor, M., Bourguignon, M., Hamedani, G. G. (2016). The beta odd log-logistic generalized family of distributions. Hacettepe Journal of Mathematics and Statistics, 45(4), 1175-1202.
x <- seq(0, 1, length.out = 21) pbollg(x) pbollg(x, alpha = 2, a = 2, b = 2, G = pbeta, shape1 = 1, shape2 = 2) dbollg(x, alpha = 2, a = 2, b = 2, G = pbeta, shape1 = 1, shape2 = 2) curve(dbollg, -3, 3) qbollg(x, alpha = 2, a = 2, b = 2, G = pbeta, shape1 = 1, shape2 = 2) n <- 10 rbollg(n, alpha = 2, a = 2, b = 2, G = pbeta, shape1 = 1, shape2 = 2) hbollg(x, alpha = 2, a = 2, b = 2, G = pbeta, shape1 = 1, shape2 = 2) curve(hbollg, -3, 3)x <- seq(0, 1, length.out = 21) pbollg(x) pbollg(x, alpha = 2, a = 2, b = 2, G = pbeta, shape1 = 1, shape2 = 2) dbollg(x, alpha = 2, a = 2, b = 2, G = pbeta, shape1 = 1, shape2 = 2) curve(dbollg, -3, 3) qbollg(x, alpha = 2, a = 2, b = 2, G = pbeta, shape1 = 1, shape2 = 2) n <- 10 rbollg(n, alpha = 2, a = 2, b = 2, G = pbeta, shape1 = 1, shape2 = 2) hbollg(x, alpha = 2, a = 2, b = 2, G = pbeta, shape1 = 1, shape2 = 2) curve(hbollg, -3, 3)
Computes the pdf, cdf, hdf, quantile and random numbers of the beta extended distribution due to Alizadeh et al. (2020) specified by the pdf
for any valid continuous cdf , , the corresponding pdf, , the first shape parameter, and , the second shape parameter.
peollg(x, alpha = 1, beta = 1, G = pnorm, ...) deollg(x, alpha = 1, beta = 1, G = pnorm, ...) qeollg(q, alpha = 1, beta = 1, G = pnorm, ...) reollg(n, alpha = 1, beta = 1, G = pnorm, ...) heollg(x, alpha = 1, beta = 1, G = pnorm, ...)peollg(x, alpha = 1, beta = 1, G = pnorm, ...) deollg(x, alpha = 1, beta = 1, G = pnorm, ...) qeollg(q, alpha = 1, beta = 1, G = pnorm, ...) reollg(n, alpha = 1, beta = 1, G = pnorm, ...) heollg(x, alpha = 1, beta = 1, G = pnorm, ...)
x |
scaler or vector of values at which the pdf or cdf needs to be computed. |
alpha |
the value of the first shape parameter, must be positive, the default is 1. |
beta |
the value of the second shape parameter, must be positive, the default is 1. |
G |
A baseline continuous cdf. |
... |
The baseline cdf parameters. |
q |
scaler or vector of probabilities at which the quantile needs to be computed. |
n |
number of random numbers to be generated. |
peollg gives the distribution function,
deollg gives the density,
qeollg gives the quantile function,
heollg gives the hazard function and
reollg generates random variables from the Exponentiated Odd log-logistic family of
distributions (EOLL-G) for baseline cdf G.
ALIZADEH, Morad; TAHMASEBI, Saeid; HAGHBIN, Hossein. The exponentiated odd log-logistic family of distributions: Properties and applications. Journal of Statistical Modelling: Theory and Applications, 2020, 1. Jg., Nr. 1, S. 29-52.
x <- seq(0, 1, length.out = 21) peollg(x) peollg(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) deollg(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) curve(deollg, -3, 3) qeollg(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) n <- 10 reollg(n, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) heollg(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) curve(heollg, -3, 3)x <- seq(0, 1, length.out = 21) peollg(x) peollg(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) deollg(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) curve(deollg, -3, 3) qeollg(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) n <- 10 reollg(n, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) heollg(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) curve(heollg, -3, 3)
Computes the pdf, cdf, hdf, quantile and random numbers of the beta extended distribution due to Cordeiro et al. (2017) specified by the pdf
for any valid continuous cdf , , the corresponding pdf, , the first shape parameter, and , the second shape parameter.
pgollg(x, alpha = 1, beta = 1, G = pnorm, ...) dgollg(x, alpha = 1, beta = 1, G = pnorm, ...) qgollg(q, alpha = 1, beta = 1, G = pnorm, ...) rgollg(n, alpha = 1, beta = 1, G = pnorm, ...) hgollg(x, alpha = 1, beta = 1, G = pnorm, ...)pgollg(x, alpha = 1, beta = 1, G = pnorm, ...) dgollg(x, alpha = 1, beta = 1, G = pnorm, ...) qgollg(q, alpha = 1, beta = 1, G = pnorm, ...) rgollg(n, alpha = 1, beta = 1, G = pnorm, ...) hgollg(x, alpha = 1, beta = 1, G = pnorm, ...)
x |
scaler or vector of values at which the pdf or cdf needs to be computed. |
alpha |
the value of the first shape parameter, must be positive, the default is 1. |
beta |
the value of the second shape parameter, must be positive, the default is 1. |
G |
A baseline continuous cdf. |
... |
The baseline cdf parameters. |
q |
scaler or vector of probabilities at which the quantile needs to be computed. |
n |
number of random numbers to be generated. |
pgollg gives the distribution function,
dgollg gives the density,
qgollg gives the quantile function,
hgollg gives the hazard function and
rgollg generates random variables from the Generalized Odd log-logistic family of
distributions (GOLL-G) for baseline cdf G.
Cordeiro, G.M., Alizadeh, M., Ozel, G., Hosseini, B., Ortega, E.M.M., Altun, E. (2017). The generalized odd log-logistic family of distributions : properties, regression models and applications. Journal of Statistical Computation and Simulation ,87(5),908-932.
x <- seq(0, 1, length.out = 21) pgollg(x) pgollg(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) dgollg(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) curve(dgollg, -3, 3) qgollg(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) n <- 10 rgollg(n, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) hgollg(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) curve(hgollg, -3, 3)x <- seq(0, 1, length.out = 21) pgollg(x) pgollg(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) dgollg(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) curve(dgollg, -3, 3) qgollg(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) n <- 10 rgollg(n, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) hgollg(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) curve(hgollg, -3, 3)
Computes the pdf, cdf, hdf, quantile and random numbers of the beta extended distribution due to Alizadeh et al. (2017) specified by the pdf
for any valid continuous cdf , , the corresponding pdf, , the shape parameter, , the first shape parameter.
pkwollg(x, alpha = 1, a = 1, b = 1, G = pnorm, ...) dkwollg(x, alpha = 1, a = 1, b = 1, G = pnorm, ...) qkwollg(q, alpha = 1, a = 1, b = 1, G = pnorm, ...) rkwollg(n, alpha = 1, a = 1, b = 1, G = pnorm, ...) hkwollg(x, alpha = 1, a = 1, b = 1, G = pnorm, ...)pkwollg(x, alpha = 1, a = 1, b = 1, G = pnorm, ...) dkwollg(x, alpha = 1, a = 1, b = 1, G = pnorm, ...) qkwollg(q, alpha = 1, a = 1, b = 1, G = pnorm, ...) rkwollg(n, alpha = 1, a = 1, b = 1, G = pnorm, ...) hkwollg(x, alpha = 1, a = 1, b = 1, G = pnorm, ...)
x |
scaler or vector of values at which the pdf or cdf needs to be computed. |
alpha |
the value of the first shape parameter, must be positive, the default is 1. |
a |
the value of the shape parameter, must be positive, the default is 1. |
b |
the value of the shape parameter, must be positive, the default is 1. |
G |
A baseline continuous cdf. |
... |
The baseline cdf parameters. |
q |
scaler or vector of probabilities at which the quantile needs to be computed. |
n |
number of random numbers to be generated. |
pkwollg gives the distribution function,
dkwollg gives the density,
qkwollg gives the quantile function,
hkwollg gives the hazard function and
rkwollg generates random variables from the Kumaraswamy Odd log-logistic family of
distributions (KwOLL-G) for baseline cdf G.
Alizadeh, M., Emadi, M., Doostparast, M., Cordeiro, G. M., Ortega, E. M., Pescim, R. R. (2015). A new family of distributions: the Kumaraswamy odd log-logistic, properties and applications. Hacettepe Journal of Mathematics and Statistics, 44(6), 1491-1512.
x <- seq(0, 1, length.out = 21) pkwollg(x) pkwollg(x, alpha = 2, a = 2, b = 2, G = pbeta, shape1 = 1, shape2 = 2) dkwollg(x, alpha = 2, a = 2, b = 2, G = pbeta, shape1 = 1, shape2 = 2) curve(dkwollg, -3, 3) qkwollg(x, alpha = 2, a = 2, b = 2, G = pbeta, shape1 = 1, shape2 = 2) n <- 10 rkwollg(n, alpha = 2, a = 2, b = 2, G = pbeta, shape1 = 1, shape2 = 2) hkwollg(x, alpha = 2, a = 2, b = 2, G = pbeta, shape1 = 1, shape2 = 2) curve(hkwollg, -3, 3)x <- seq(0, 1, length.out = 21) pkwollg(x) pkwollg(x, alpha = 2, a = 2, b = 2, G = pbeta, shape1 = 1, shape2 = 2) dkwollg(x, alpha = 2, a = 2, b = 2, G = pbeta, shape1 = 1, shape2 = 2) curve(dkwollg, -3, 3) qkwollg(x, alpha = 2, a = 2, b = 2, G = pbeta, shape1 = 1, shape2 = 2) n <- 10 rkwollg(n, alpha = 2, a = 2, b = 2, G = pbeta, shape1 = 1, shape2 = 2) hkwollg(x, alpha = 2, a = 2, b = 2, G = pbeta, shape1 = 1, shape2 = 2) curve(hkwollg, -3, 3)
Computes the pdf, cdf, hdf, quantile and random numbers of the beta extended distribution due to Gleaton et al. (2010) specified by the pdf
for any valid continuous cdf , , the corresponding pdf, , the first shape parameter, and , the second shape parameter.
pmoollg(x, alpha = 1, beta = 1, G = pnorm, ...) dmoollg(x, alpha = 1, beta = 1, G = pnorm, ...) qmoollg(q, alpha = 1, beta = 1, G = pnorm, ...) rmoollg(n, alpha = 1, beta = 1, G = pnorm, ...) hmoollg(x, alpha = 1, beta = 1, G = pnorm, ...)pmoollg(x, alpha = 1, beta = 1, G = pnorm, ...) dmoollg(x, alpha = 1, beta = 1, G = pnorm, ...) qmoollg(q, alpha = 1, beta = 1, G = pnorm, ...) rmoollg(n, alpha = 1, beta = 1, G = pnorm, ...) hmoollg(x, alpha = 1, beta = 1, G = pnorm, ...)
x |
scaler or vector of values at which the pdf or cdf needs to be computed. |
alpha |
the value of the first shape parameter, must be positive, the default is 1. |
beta |
the value of the second shape parameter, must be positive, the default is 1. |
G |
A baseline continuous cdf. |
... |
The baseline cdf parameters. |
q |
scaler or vector of probabilities at which the quantile needs to be computed. |
n |
number of random numbers to be generated. |
pmoollg gives the distribution function,
dmoollg gives the density,
qmoollg gives the quantile function,
hmoollg gives the hazard function and
rmoollg generates random variables from the Marshal-Olkin Odd log-logistic family of
distributions (MOOLL-G) for baseline cdf G.
Gleaton, J. U., Lynch, J. D. (2010). Extended generalized loglogistic families of lifetime distributions with an application. J. Probab. Stat.Sci, 8(1), 1-17.
x <- seq(0, 1, length.out = 21) pmoollg(x) pmoollg(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) dmoollg(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) curve(dmoollg, -3, 3) qmoollg(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) n <- 10 rmoollg(n, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) hmoollg(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) curve(hmoollg, -3, 3)x <- seq(0, 1, length.out = 21) pmoollg(x) pmoollg(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) dmoollg(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) curve(dmoollg, -3, 3) qmoollg(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) n <- 10 rmoollg(n, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) hmoollg(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) curve(hmoollg, -3, 3)
Computes the pdf, cdf, hdf, quantile and random numbers of the beta extended distribution due to Alizadeh et al. (2019) specified by the pdf
for any valid continuous cdf , , the corresponding pdf, , the first shape parameter, and , the second shape parameter.
pnollg(x, alpha = 1, beta = 1, G = pnorm, ...) dnollg(x, alpha = 1, beta = 1, G = pnorm, ...) qnollg(q, alpha = 1, beta = 1, G = pnorm, ...) rnollg(n, alpha = 1, beta = 1, G = pnorm, ...) hnollg(x, alpha = 1, beta = 1, G = pnorm, ...)pnollg(x, alpha = 1, beta = 1, G = pnorm, ...) dnollg(x, alpha = 1, beta = 1, G = pnorm, ...) qnollg(q, alpha = 1, beta = 1, G = pnorm, ...) rnollg(n, alpha = 1, beta = 1, G = pnorm, ...) hnollg(x, alpha = 1, beta = 1, G = pnorm, ...)
x |
scaler or vector of values at which the pdf or cdf needs to be computed. |
alpha |
the value of the first shape parameter, must be positive, the default is 1. |
beta |
the value of the second shape parameter, must be positive, the default is 1. |
G |
A baseline continuous cdf. |
... |
The baseline cdf parameters. |
q |
scaler or vector of probabilities at which the quantile needs to be computed. |
n |
number of random numbers to be generated. |
pnollg gives the distribution function,
dnollg gives the density,
qnollg gives the quantile function,
hnollg gives the hazard function and
rnollg generates random variables from the New Odd log-logistic family of
distributions (NOLL-G) for baseline cdf G.
Alizadeh, M., Altun, E., Ozel, G., Afshari, M., Eftekharian, A. (2019). A new odd log-logistic lindley distribution with properties and applications. Sankhya A, 81(2), 323-346.
x <- seq(0, 1, length.out = 21) pnollg(x) pnollg(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) dnollg(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) curve(dnollg, -3, 3) qnollg(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) n <- 10 rnollg(n, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) hnollg(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) curve(hnollg, -3, 3)x <- seq(0, 1, length.out = 21) pnollg(x) pnollg(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) dnollg(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) curve(dnollg, -3, 3) qnollg(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) n <- 10 rnollg(n, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) hnollg(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) curve(hnollg, -3, 3)
Computes the pdf, cdf, hdf, quantile and random numbers of the beta extended distribution due to Alizadeh et al. (2017) specified by the pdf
for any valid continuous cdf , , the corresponding pdf, , the first shape parameter, and , the second shape parameter.
pobug(x, alpha = 1, beta = 1, G = pnorm, ...) dobug(x, alpha = 1, beta = 1, G = pnorm, ...) qobug(q, alpha = 1, beta = 1, G = pnorm, ...) robug(n, alpha = 1, beta = 1, G = pnorm, ...) hobug(x, alpha = 1, beta = 1, G = pnorm, ...)pobug(x, alpha = 1, beta = 1, G = pnorm, ...) dobug(x, alpha = 1, beta = 1, G = pnorm, ...) qobug(q, alpha = 1, beta = 1, G = pnorm, ...) robug(n, alpha = 1, beta = 1, G = pnorm, ...) hobug(x, alpha = 1, beta = 1, G = pnorm, ...)
x |
scaler or vector of values at which the pdf or cdf needs to be computed. |
alpha |
the value of the first shape parameter, must be positive, the default is 1. |
beta |
the value of the second shape parameter, must be positive, the default is 1. |
G |
A baseline continuous cdf. |
... |
The baseline cdf parameters. |
q |
scaler or vector of probabilities at which the quantile needs to be computed. |
n |
number of random numbers to be generated. |
pobug gives the distribution function,
dobug gives the density,
qobug gives the quantile function,
hobug gives the hazard function and
robug generates random variables from the Odd Burr generated family of
distributions (OBu-G) for baseline cdf G.
Alizadeh, M., Cordeiro, G. M., Nascimento, A. D., Lima, M. D. C. S., Ortega, E. M. (2017). Odd-Burr generalized family of distributions with some applications. Journal of statistical computation and simulation, 87(2), 367-389.
x <- seq(0, 1, length.out = 21) pobug(x) pobug(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) dobug(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) curve(dobug, -3, 3) qobug(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) n <- 10 robug(n, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) hobug(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) curve(hobug, -3, 3)x <- seq(0, 1, length.out = 21) pobug(x) pobug(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) dobug(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) curve(dobug, -3, 3) qobug(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) n <- 10 robug(n, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) hobug(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) curve(hobug, -3, 3)
Computes the pdf, cdf, hdf, quantile and random numbers of the beta extended distribution due to Gleaton et al. (2006) specified by the pdf
for any valid continuous cdf , , the corresponding pdf, , the first shape parameter.
pollg(x, alpha = 1, G = pnorm, ...) dollg(x, alpha = 1, G = pnorm, ...) qollg(q, alpha = 1, G = pnorm, ...) rollg(n, alpha = 1, G = pnorm, ...) hollg(x, alpha = 1, G = pnorm, ...)pollg(x, alpha = 1, G = pnorm, ...) dollg(x, alpha = 1, G = pnorm, ...) qollg(q, alpha = 1, G = pnorm, ...) rollg(n, alpha = 1, G = pnorm, ...) hollg(x, alpha = 1, G = pnorm, ...)
x |
scaler or vector of values at which the pdf or cdf needs to be computed. |
alpha |
the value of the first shape parameter, must be positive, the default is 1. |
G |
A baseline continuous cdf. |
... |
The baseline cdf parameters. |
q |
scaler or vector of probabilities at which the quantile needs to be computed. |
n |
number of random numbers to be generated. |
pollg gives the distribution function,
dollg gives the density,
qollg gives the quantile function,
hollg gives the hazard function and
rollg generates random variables from the Odd log-logistic family of
distributions (OLL-G) for baseline cdf G.
Gleaton, J. U., Lynch, J. D. (2006). Properties of generalized log-logistic families of lifetime distributions. Journal of Probability and Statistical Science, 4(1), 51-64.
x <- seq(0, 1, length.out = 21) pollg(x) pollg(x, alpha = 2, G = pbeta, shape1 = 1, shape2 = 2) dollg(x, alpha = 2, G = pbeta, shape1 = 1, shape2 = 2) curve(dollg, -3, 3) qollg(x, alpha = 2, G = pbeta, shape1 = 1, shape2 = 2) n <- 10 rollg(n, alpha = 2, G = pbeta, shape1 = 1, shape2 = 2) hollg(x, alpha = 2, G = pbeta, shape1 = 1, shape2 = 2) curve(hollg, -3, 3)x <- seq(0, 1, length.out = 21) pollg(x) pollg(x, alpha = 2, G = pbeta, shape1 = 1, shape2 = 2) dollg(x, alpha = 2, G = pbeta, shape1 = 1, shape2 = 2) curve(dollg, -3, 3) qollg(x, alpha = 2, G = pbeta, shape1 = 1, shape2 = 2) n <- 10 rollg(n, alpha = 2, G = pbeta, shape1 = 1, shape2 = 2) hollg(x, alpha = 2, G = pbeta, shape1 = 1, shape2 = 2) curve(hollg, -3, 3)
Computes the pdf, cdf, hdf, quantile and random numbers of the beta extended distribution due to Haghbin et al. (2017) specified by the pdf
for any valid continuous cdf , , the corresponding pdf, , the first shape parameter, and , the second shape parameter.
polllg(x, alpha = 1, beta = 0.1, G = pnorm, ...) dolllg(x, alpha = 1, beta = 0.1, G = pnorm, ...) qolllg(q, alpha = 1, beta = 0.1, G = pnorm, ...) rolllg(n, alpha = 1, beta = 0.1, G = pnorm, ...) holllg(x, alpha = 1, beta = 0.1, G = pnorm, ...)polllg(x, alpha = 1, beta = 0.1, G = pnorm, ...) dolllg(x, alpha = 1, beta = 0.1, G = pnorm, ...) qolllg(q, alpha = 1, beta = 0.1, G = pnorm, ...) rolllg(n, alpha = 1, beta = 0.1, G = pnorm, ...) holllg(x, alpha = 1, beta = 0.1, G = pnorm, ...)
x |
scaler or vector of values at which the pdf or cdf needs to be computed. |
alpha |
the value of the first shape parameter, must be positive, the default is 1. |
beta |
the value of the second shape parameter, between 0 and 1, the default is 0.1. |
G |
A baseline continuous cdf. |
... |
The baseline cdf parameters. |
q |
scaler or vector of probabilities at which the quantile needs to be computed. |
n |
number of random numbers to be generated. |
polllg gives the distribution function,
dolllg gives the density,
qolllg gives the quantile function,
holllg gives the hazard function and
rolllg generates random variables from the Odd log-logistic logarithmic family of
distributions (OLLL-G) for baseline cdf G.
Alizadeh, M., MirMostafee, S. M. T. K., Ortega, E. M., Ramires, T. G., Cordeiro, G. M. (2017). The odd log-logistic logarithmic generated family of distributions with applications in different areas. Journal of Statistical Distributions and Applications, 4(1), 1-25.
x <- seq(0, 1, length.out = 21) polllg(x) polllg(x, alpha = 2, beta = .2, G = pbeta, shape1 = 1, shape2 = 2) dolllg(x, alpha = 2, beta = .2, G = pbeta, shape1 = 1, shape2 = 2) curve(dolllg, -3, 3) qolllg(x, alpha = 2, beta = .2, G = pbeta, shape1 = 1, shape2 = 2) n <- 10 rolllg(n, alpha = 2, beta = .2, G = pbeta, shape1 = 1, shape2 = 2) holllg(x, alpha = 2, G = pbeta, beta = .2, shape1 = 1, shape2 = 2) curve(holllg, -3, 3)x <- seq(0, 1, length.out = 21) polllg(x) polllg(x, alpha = 2, beta = .2, G = pbeta, shape1 = 1, shape2 = 2) dolllg(x, alpha = 2, beta = .2, G = pbeta, shape1 = 1, shape2 = 2) curve(dolllg, -3, 3) qolllg(x, alpha = 2, beta = .2, G = pbeta, shape1 = 1, shape2 = 2) n <- 10 rolllg(n, alpha = 2, beta = .2, G = pbeta, shape1 = 1, shape2 = 2) holllg(x, alpha = 2, G = pbeta, beta = .2, shape1 = 1, shape2 = 2) curve(holllg, -3, 3)
Computes the pdf, cdf, hdf, quantile and random numbers of the beta extended distribution due to Esmaeili et al. (2020) specified by the pdf
for any valid continuous cdf , , the corresponding pdf, the Gamma funcion, , the first shape parameter, and , the second shape parameter.
prbollg(x, alpha = 1, beta = 1, G = pnorm, ...) drbollg(x, alpha = 1, beta = 1, G = pnorm, ...) qrbollg(q, alpha = 1, beta = 1, G = pnorm, ...) rrbollg(n, alpha = 1, beta = 1, G = pnorm, ...) hrbollg(x, alpha = 1, beta = 1, G = pnorm, ...)prbollg(x, alpha = 1, beta = 1, G = pnorm, ...) drbollg(x, alpha = 1, beta = 1, G = pnorm, ...) qrbollg(q, alpha = 1, beta = 1, G = pnorm, ...) rrbollg(n, alpha = 1, beta = 1, G = pnorm, ...) hrbollg(x, alpha = 1, beta = 1, G = pnorm, ...)
x |
scaler or vector of values at which the pdf or cdf needs to be computed. |
alpha |
the value of the first shape parameter, must be positive, the default is 1. |
beta |
the value of the second shape parameter, must be positive, the default is 1. |
G |
A baseline continuous cdf. |
... |
The baseline cdf parameters. |
q |
scaler or vector of probabilities at which the quantile needs to be computed. |
n |
number of random numbers to be generated. |
prbollg gives the distribution function,
drbollg gives the density,
qrbollg gives the quantile function,
hrbollg gives the hazard function and
rrbollg generates random variables from the The Ristic-Balakrishnan Odd log-logistic family of
distributions (RBOLL-G) for baseline cdf G.
Esmaeili, H., Lak, F., Altun, E. (2020). The Ristic-Balakrishnan odd log-logistic family of distributions: Properties and Applications. Statistics, Optimization Information Computing, 8(1), 17-35.
x <- seq(0, 1, length.out = 21) prbollg(x) prbollg(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) drbollg(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) curve(drbollg, -3, 3) qrbollg(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) n <- 10 rrbollg(n, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) hrbollg(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) curve(hrbollg, -3, 3)x <- seq(0, 1, length.out = 21) prbollg(x) prbollg(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) drbollg(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) curve(drbollg, -3, 3) qrbollg(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) n <- 10 rrbollg(n, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) hrbollg(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) curve(hrbollg, -3, 3)
Computes the pdf, cdf, hdf, quantile and random numbers of the beta extended distribution due to Cordeiro et al. (2016) specified by the pdf
for any valid continuous cdf , , the corresponding pdf, the Gamma funcion, , the first shape parameter, and , the second shape parameter.
pzbollg(x, alpha = 1, beta = 1, G = pnorm, ...) dzbollg(x, alpha = 1, beta = 1, G = pnorm, ...) qzbollg(q, alpha = 1, beta = 1, G = pnorm, ...) rzbollg(n, alpha = 1, beta = 1, G = pnorm, ...) hzbollg(x, alpha = 1, beta = 1, G = pnorm, ...)pzbollg(x, alpha = 1, beta = 1, G = pnorm, ...) dzbollg(x, alpha = 1, beta = 1, G = pnorm, ...) qzbollg(q, alpha = 1, beta = 1, G = pnorm, ...) rzbollg(n, alpha = 1, beta = 1, G = pnorm, ...) hzbollg(x, alpha = 1, beta = 1, G = pnorm, ...)
x |
scaler or vector of values at which the pdf or cdf needs to be computed. |
alpha |
the value of the first shape parameter, must be positive, the default is 1. |
beta |
the value of the second shape parameter, must be positive, the default is 1. |
G |
A baseline continuous cdf. |
... |
The baseline cdf parameters. |
q |
scaler or vector of probabilities at which the quantile needs to be computed. |
n |
number of random numbers to be generated. |
pzbollg gives the distribution function,
dzbollg gives the density,
qzbollg gives the quantile function,
hzbollg gives the hazard function and
rzbollg generates random variables from the The Zografos-Balakrishnan Odd log-logistic family of
distributions (ZBOLL-G) for baseline cdf G.
Cordeiro, G. M., Alizadeh, M., Ortega, E. M., Serrano, L. H. V. (2016). The Zografos-Balakrishnan odd log-logistic family of distributions: Properties and Applications. Hacettepe Journal of Mathematics and Statistics, 45(6), 1781-1803. .
x <- seq(0, 1, length.out = 21) pzbollg(x) pzbollg(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) dzbollg(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) curve(dzbollg, -3, 3) qzbollg(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) n <- 10 rzbollg(n, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) hzbollg(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) curve(hzbollg, -3, 3)x <- seq(0, 1, length.out = 21) pzbollg(x) pzbollg(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) dzbollg(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) curve(dzbollg, -3, 3) qzbollg(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) n <- 10 rzbollg(n, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) hzbollg(x, alpha = 2, beta = 2, G = pbeta, shape1 = 1, shape2 = 2) curve(hzbollg, -3, 3)